summaryrefslogtreecommitdiffstats
path: root/ktouch/src/ktouchkeyboard.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-21 14:20:25 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-21 14:20:25 -0600
commitba6b21419810544e0c8666969d21d72161d9084c (patch)
tree1850cd178553cd190ab7194f3b318e23ce7c98c6 /ktouch/src/ktouchkeyboard.h
parent746abe84406ed1ec1a8dc68f29ce0ab8322ccc80 (diff)
downloadtdeedu-ba6b21419810544e0c8666969d21d72161d9084c.tar.gz
tdeedu-ba6b21419810544e0c8666969d21d72161d9084c.zip
Rename obsolete tq methods to standard names
Diffstat (limited to 'ktouch/src/ktouchkeyboard.h')
-rw-r--r--ktouch/src/ktouchkeyboard.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/ktouch/src/ktouchkeyboard.h b/ktouch/src/ktouchkeyboard.h
index 0e2ebfd6..fa88bed5 100644
--- a/ktouch/src/ktouchkeyboard.h
+++ b/ktouch/src/ktouchkeyboard.h
@@ -24,7 +24,7 @@
class KURL;
/// This class stores the keyboard tqlayout and the connectivity between characters
/// and the actual keys.
class KTouchKeyboard {
public:
@@ -32,7 +32,7 @@ class KTouchKeyboard {
KTouchKeyboard() { createDefault(); }
/// Clears the keyboard (resets all data)
void clear();
/// Loads a keyboard tqlayout (old format) from file (returns true if successful).
bool load(TQWidget * window, const KURL& url);
/// Loads a lecture (in XML format) from file (returns true if successful).
bool loadXML(TQWidget * window, const KURL& url);
@@ -47,7 +47,7 @@ class KTouchKeyboard {
TQValueVector<KTouchKeyConnector> m_connectors; ///< Vector with connectivity data.
TQString m_title; ///< Title of the keyboard (to appear in the menu).
- TQString m_comment; ///< Comments about the creator of the keyboard tqlayout.
+ TQString m_comment; ///< Comments about the creator of the keyboard layout.
TQString m_language; ///< Language ID of keyboard
TQString m_fontSuggestions; ///< Suggestions of fonts to be used on the keys.
@@ -24,7 +24,7 @@
class KURL;
-/// This class stores the keyboard tqlayout and the connectivity between characters
+/// This class stores the keyboard layout and the connectivity between characters
/// and the actual keys.
class KTouchKeyboard {
@@ -32,7 +32,7 @@ class KTouchKeyboard {
/// Clears the keyboard (resets all data)
void clear();
- /// Loads a keyboard tqlayout (old format) from file (returns true if successful).
+ /// Loads a keyboard layout (old format) from file (returns true if successful).
bool load(TQWidget * window, const KURL& url);
/// Loads a lecture (in XML format) from file (returns true if successful).